@@ -27,6 +27,10 @@ class AppSettings(BaseSettings):
 
     BUILD_NUMBER: str = ""
     """Identifier for CI build."""
+    CHECK_DB_READY: bool = True
+    """Check for database readiness on startup."""
+    CHECK_REDIS_READY: bool = True
+    """Check for redis readiness on startup."""
     DEBUG: bool = False
     """Run `Starlite` with `debug=True`."""
     ENVIRONMENT: str = "prod"
@@ -235,7 +239,7 @@ class ServerSettings(BaseSettings):
     """Seconds to hold connections open (65 is > AWS lb idle timeout)."""
     PORT: int = 8000
     """Server port."""
-    RELOAD: bool = False
+    RELOAD: bool | None = None
     """Turn on hot reloading."""
     RELOAD_DIRS: list[str] = ["src/"]
     """Directories to watch for reloading."""
